"""
Author: El Hovik
Code to support Scantron File IO Case Study to 
randomly-generate a number of test Scantron files for use 
in scantron_grader.py.

We'll implement scantron_grader.py in Lecture 10 to
get practice with processing two files at a time with
various possible design decisions.
"""
import random


def create_random_file(filename):
    """
    Randomly generates a 20-question Scantron .txt
    file for the given `filename` with answers A-E, one answer per line.

    Arguments: 
        `filename` (str) - name of new file to create, overwriting
                           such file if it exists.

    Returns:
        (None)
    """
    options = 'ABCDE'
    f = open(filename, 'w')
    # We should use _ instead of i since we don't
    # use the i variable here.
    for _ in range(20):
        ans = random.choice(options)
        f.write(ans + '\n')
    f.close()


def create_n_test_files(n):
    """
    Creates `n` test files randomly in the format
    samples/test-x.txt where x is between [1, n).
    Overwrites any files in this format that
    may already exist.

    Arguments:
        `n` (int) - # of files to create (must be > 0)

    Returns:
        None
    """
    for i in range(1, n):
        create_random_file(f'samples/test{i}.txt')


if __name__ == '__main__':
    TEST_FILE_COUNT = 10
    create_n_test_files(TEST_FILE_COUNT)
